@@ -29,6 +29,9 @@ use warnings;
 
 use Carp;
 
+use vars qw($VERSION);
+$VERSION = "0.31";
+
 =head1 CONSTRUCTOR
 
 =head2 new (params)
@@ -73,7 +76,7 @@ L<PICA::XMLParser> is used instead.
 
 Common parameters that are passed to the specific parser are:
 
-=over 4
+=over
 
 =item Field
 
@@ -85,12 +88,11 @@ L<PICA::Field> object is returned then it will be skipped.
 
 =item Record
 
-Reference to a handler function for parsed PICA+ records. The 
-function is passed a L<PICA::Record>. If the function returns 
-a record then this record will be stored in an array that is 
-passed to C<EndCollection>. You can use this method as a filter 
-by returning a modified record, but for performance reasons it 
-is recommended to directly use the record instead of storing it.
+Reference to a handler function for parsed PICA+ records. The
+function is passed a L<PICA::Record>. If the function returns
+a record then this record will be stored in an array that is
+passed to C<EndCollection>. You can use this method as a filter
+by returning a modified record.
 
 =item Collection
 
@@ -98,24 +100,33 @@ Alias for C<EndCollection>. Ignored if C<EndCollection> is specified.
 
 =item StartCollection
 
-Reference to a handler function that is called before a 
-collection of PICA+ record. Each file is treated as a 
+Reference to a handler function that is called before a
+collection of PICA+ record. Each file is treated as a
 collection so this is called before parsing a file.
 
 =item EndCollection
 
-Reference to a handler function for parsed PICA+ collections. 
+Reference to a handler function for parsed PICA+ collections.
 An array of L<PICA::Record> objects is passed to the function.
+For performace reasons it is recommended to directly use the
+stream of records with the L<Record> handler instead of collecting
+all storing records and using them afterwards.
 
-=back
+=item Error
 
-Additionally the following parameters are known to most parsers:
+This handler is used if an error occured while parsing, for instance
+if data does not look like PICA+. By default errors are just ignored.
 
-=over 4
+All errors are counted, the number of errors is given in the 
+L<errors> method.
 
 =item Strict
 
-Stop on errors (default is false)
+TODO: strict_mode only available in PlainParser which needs to be implemented
+TODO: @ISA!
+
+Stop on errors. By default a parser just omits records that could
+not been parsed. (default is false).
 
 =item EmptyRecords
 
@@ -124,11 +135,13 @@ Skip empty records so they will not be passed to the record handler
 field handler does not return anything - this is useful for performance 
 but you should not forget to set the EmptyRecords parameter. In every
 case empty records are counted with a special counter that can be read 
-with the C<empty_counter> method. The normal counter (method C<counter>) 
+with the C<empty> method. The normal counter (method C<counter>) 
 counts all records no matter if empty or not.
 
 =back
 
+Specific parser may support additional handlers or parameters.
+
 =cut
 
 sub parsefile {
@@ -196,22 +209,36 @@ sub counter {
    return $parser->counter() if $parser;
 }
 
-=head2 empty_counter
+=head2 empty
 
 Get the number of empty records that have been read so far.
 Empty records are counted but not passed to the record handler 
 unless you specify the C<EmptyRecords> parameter. The number
 of non-empty records is the difference between C<counter> 
-and C<empty_counter>.
+and C<empty>.
 
 =cut
 
-sub empty_counter {
+sub empty {
    my $self = shift; 
    return undef if !ref $self;
 
    my $parser = $self->{parser};
-   return $parser->empty_counter() if $parser;
+   return $parser->empty() if $parser;
+}
+
+=head2 errors
+
+Return the number of errors that ocurred so far.
+
+=cut
+
+sub errors {
+   my $self = shift;
+   return undef if !ref $self;
+
+   my $parser = $self->{parser};
+   return $parser->errors() if $parser;
 }
 
 1;
@@ -220,9 +247,10 @@ __END__
 
 =head1 TODO
 
-Better logging needs to be added, for instance a status message every n records. This 
-me be implemented with multiple handlers per record (maybe piped). Handling of broken 
-records should also be improved.
+Support multiple handlers per record?
+Better logging needs to be added, for instance a status message every n records.
+This may be implemented with multiple handlers per record (maybe piped). 
+Handling of broken records should also be improved.
 
 =head1 AUTHOR
 
@@ -230,12 +258,8 @@ Jakob Voss C<< <jakob.voss@gbv.de> >>
 
 =head1 LICENSE
 
-Copyright (C) 2007 by Verbundzentrale Göttingen (VZG) and Jakob Voss
+Copyright (C) 2007 by Verbundzentrale Goettingen (VZG) and Jakob Voss
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself, either Perl version 5.8.8 or, at
 your option, any later version of Perl 5 you may have available.
-
-Please note that these module s not product of or supported by the 
-employers of the various contributors to the code nor by OCLC PICA.
-
