@@ -48,6 +48,9 @@ require XML::Parser;
 
 use Carp;
 
+use vars qw($VERSION);
+$VERSION = "0.31";
+
 =head1 PUBLIC METHODS
 
 =head2 new
@@ -78,7 +81,7 @@ sub new {
         collection_handler => $params{Collection} ? $params{Collection} : undef,
 
         read_counter => 0,
-        empty_counter => 0
+        empty => 0
     };
     bless $self, $class;
     return $self;
@@ -97,7 +100,7 @@ sub parsedata {
     my ($self, $data) = @_;
 
     $self->{read_counter} = 0;
-    $self->{empty_counter} = 0;
+    $self->{empty} = 0;
 
     my $parser = new XML::Parser(
         Handlers => $self->_getHandlers
@@ -128,7 +131,7 @@ sub parsefile {
     my ($self, $file) = @_;
 
     $self->{read_counter} = 0;
-    $self->{empty_counter} = 0;
+    $self->{empty} = 0;
 
     $self->{filename} = $file if ref(\$file) eq 'SCALAR';
     my $parser = new XML::Parser(
@@ -153,7 +156,7 @@ sub counter {
    return $self->{read_counter};
 }
 
-=head2 empty_counter
+=head2 empty
 
 Get the number of empty records that have been read so far.
 By default empty records are not passed to the record handler
@@ -161,9 +164,9 @@ but counted.
 
 =cut
 
-sub empty_counter {
+sub empty {
    my $self = shift; 
-   return $self->{empty_counter};
+   return $self->{empty};
 }
 
 =head1 PRIVATE HANDLERS
@@ -209,7 +212,7 @@ sub start_handler {
 
         my $code = $attrs{"code"};
         if (defined $code) {
-            if ($code =~ /^.$/) { # TODO: what chars are allowed?
+            if ($code =~ PICA::Field::SUBFIELD_CODE_REGEXP) {
                 $self->{subfield_code} = $code;
                 $self->{subfield_value} = "";
             } else {
@@ -221,14 +224,14 @@ sub start_handler {
     } elsif ($name eq "field" or $name eq "datafield") {
         my $tag = $attrs{tag};
         if (defined $tag) {
-            if (!($tag =~ /^[0-2][0-9][0-9][A-Z@]$/)) {
+            if (!($tag =~ PICA::Field::FIELD_TAG_REGEXP)) {
                 croak("Invalid field tag '$tag'" . $self->_getPosition($parser));
             }
         } else {
             croak("Missing attribute 'tag'" . $self->_getPosition($parser));
         }
         my $occurrence = $attrs{occurrence};
-        if ($occurrence && !($occurrence =~ /^[0-9][0-9]$/)) {
+        if ($occurrence && !($occurrence =~ PICA::Field::FIELD_OCCURRENCE_REGEXP)) {
             croak("Invalid occurrence '$occurrence'" . $self->_getPosition($parser));
         }
 
@@ -285,7 +288,7 @@ sub end_handler {
 
          $self->{read_counter}++;
          # if ( $record->is_empty() ) {
-         #   $self->{empty_counter}++;
+         #   $self->{empty}++;
             # TODO: Test whether empty records should be skipped
          #}
          # TODO: add to collection
@@ -364,12 +367,9 @@ Jakob Voss C<< <jakob.voss@gbv.de> >>
 
 =head1 LICENSE
 
-Copyright (C) 2007 by Verbundzentrale Göttingen (VZG) and Jakob Voss
+Copyright (C) 2007 by Verbundzentrale Goettingen (VZG) and Jakob Voss
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself, either Perl version 5.8.8 or, at
 your option, any later version of Perl 5 you may have available.
 
-Please note that these module s not product of or supported by the 
-employers of the various contributors to the code nor by OCLC PICA.
-
